hyphen top-level constant
String
const hyphen
The hyphen a canonical form puts back after parsing, where the standard fixes its position.
Implementation
const hyphen = '-';
The hyphen a canonical form puts back after parsing, where the standard fixes its position.
const hyphen = '-';